==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/GetWorkspaceProductGroupLinkPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.GetWorkspaceProductGroupLinkPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property groupLinkId Product-Group link identifier. Must be unique in the current API Management service instance.
 * @property productId Product identifier. Must be unique in the current API Management service instance.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 * @property workspaceId Workspace identifier. Must be unique in the current API Management service instance.
 */
public data class GetWorkspaceProductGroupLinkPlainArgs(
    public val groupLinkId: String,
    public val productId: String,
    public val resourceGroupName: String,
    public val serviceName: String,
    public val workspaceId: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.GetWorkspaceProductGroupLinkPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.apimanagement.inputs.GetWorkspaceProductGroupLinkPlainArgs =
        com.pulumi.azurenative.apimanagement.inputs.GetWorkspaceProductGroupLinkPlainArgs.builder()
            .groupLinkId(groupLinkId.let({ args0 -> args0 }))
            .productId(productId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 }))
            .workspaceId(workspaceId.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetWorkspaceProductGroupLinkPlainArgs].
 */
@PulumiTagMarker
public class GetWorkspaceProductGroupLinkPlainArgsBuilder internal constructor() {
    private var groupLinkId: String? = null

    private var productId: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    private var workspaceId: String? = null

    /**
     * @param value Product-Group link identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("ceonhkqfabhgeich")
    public suspend fun groupLinkId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.groupLinkId = mapped
    }

    /**
     * @param value Product identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("ydesjspsfqvqwwig")
    public suspend fun productId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.productId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("iqoupcppaqvtulyi")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("brhirwjwcyfavrrp")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    /**
     * @param value Workspace identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("faevdoycjgjqohll")
    public suspend fun workspaceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceId = mapped
    }

    internal fun build(): GetWorkspaceProductGroupLinkPlainArgs =
        GetWorkspaceProductGroupLinkPlainArgs(
            groupLinkId = groupLinkId ?: throw PulumiNullFieldException("groupLinkId"),
            productId = productId ?: throw PulumiNullFieldException("productId"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
            workspaceId = workspaceId ?: throw PulumiNullFieldException("workspaceId"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/GetWorkspaceProductGroupLinkPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.GetWorkspaceProductGroupLinkPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property groupLinkId Product-Group link identifier. Must be unique in the current API Management service instance.
 * @property productId Product identifier. Must be unique in the current API Management service instance.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 * @property workspaceId Workspace identifier. Must be unique in the current API Management service instance.
 */
public data class GetWorkspaceProductGroupLinkPlainArgs(
    public val groupLinkId: String,
    public val productId: String,
    public val resourceGroupName: String,
    public val serviceName: String,
    public val workspaceId: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.GetWorkspaceProductGroupLinkPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.apimanagement.inputs.GetWorkspaceProductGroupLinkPlainArgs =
        com.pulumi.azurenative.apimanagement.inputs.GetWorkspaceProductGroupLinkPlainArgs.builder()
            .groupLinkId(groupLinkId.let({ args0 -> args0 }))
            .productId(productId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 }))
            .workspaceId(workspaceId.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetWorkspaceProductGroupLinkPlainArgs].
 */
@PulumiTagMarker
public class GetWorkspaceProductGroupLinkPlainArgsBuilder internal constructor() {
    private var groupLinkId: String? = null

    private var productId: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    private var workspaceId: String? = null

    /**
     * @param value Product-Group link identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("jkllwtuqejemprpr")
    public suspend fun groupLinkId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.groupLinkId = mapped
    }

    /**
     * @param value Product identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("pqjyjkbnjruvlnnq")
    public suspend fun productId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.productId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("qhfoqigatjlomfkg")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("jluwbflixfuexlmm")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    /**
     * @param value Workspace identifier. Must be unique in the current API Management service instance.
     */
    @JvmName("ystsxlskvobixqkd")
    public suspend fun workspaceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceId = mapped
    }

    internal fun build(): GetWorkspaceProductGroupLinkPlainArgs =
        GetWorkspaceProductGroupLinkPlainArgs(
            groupLinkId = groupLinkId ?: throw PulumiNullFieldException("groupLinkId"),
            productId = productId ?: throw PulumiNullFieldException("productId"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
            workspaceId = workspaceId ?: throw PulumiNullFieldException("workspaceId"),
        )
}
